*******************
`utilipy` on import
*******************

This is the documentation for the top-level of ``utilipy``, ie, what happens on import.

.. automodule:: utilipy


Subpackages
===========

.. toctree::
   :maxdepth: 1

   data_utils/index
   decorators/index
   imports/index
   ipython/index
   math/index
   plot/index
   scripts/index


Reference/API
=============

.. automodapi:: utilipy
	:include-all-objects:
	:no-main-docstr:
